@@ -10,7 +10,12 @@
 #include <TextAutoCorrectionCore/AutoCorrection>
 #include <qtestkeyboard.h>
 
-LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest() = default;
+LineEditWithAutocorrectionTest::LineEditWithAutocorrectionTest()
+{
+    if (qEnvironmentVariableIntValue("KDECI_CANNOT_CREATE_WINDOWS")) {
+        QSKIP("KDE CI can't create a window on this platform, skipping some gui tests");
+    }
+}
 
 void LineEditWithAutocorrectionTest::shouldNotAutocorrectWhenDisabled()
 {
