@@ -35,9 +35,7 @@ BroadcastStatus *BroadcastStatus::instance()
 class BroadcastStatusPrivate
 {
 public:
-    BroadcastStatusPrivate()
-    {
-    }
+    BroadcastStatusPrivate() = default;
 
     QString mStatusMsg;
     bool mTransientActive = false;
@@ -51,7 +49,6 @@ BroadcastStatus::BroadcastStatus()
 BroadcastStatus::~BroadcastStatus()
 {
     instance_ = nullptr;
-    delete d;
 }
 
 void BroadcastStatus::setStatusMsg(const QString &message)
@@ -75,3 +72,5 @@ void BroadcastStatus::reset()
     Q_EMIT statusMsg(d->mStatusMsg);
 }
 }
+
+#include "moc_broadcaststatus.cpp"
